@@ -6,59 +6,13 @@ use warnings;
 use Scalar::Util;
 use Symbol;
 use Carp;
-use Fcntl qw(F_GETFL O_WRONLY O_RDWR O_APPEND);
 
-our $VERSION = "0.05_02";
+our $VERSION = "0.01";
 
 use base 'Exporter';
 
 our @EXPORT_OK = qw( encode decode );
 
-our $HAS_FMODE;
-BEGIN {
-    $HAS_FMODE = eval { require FileHandle::Fmode } || '';
-}
-
-sub _get_open_mode_filehandle_fmode {
-    my $fh = shift;
-
-    return unless FileHandle::Fmode::is_FH($fh);
-
-    my $is_append = FileHandle::Fmode::is_A($fh);
-    if (FileHandle::Fmode::is_WO($fh)) {
-        return $is_append ? '>>' : '>';
-    } elsif (FileHandle::Fmode::is_RW($fh)) {
-        return $is_append ? '+>>' : '+<';
-    } else {
-        return '<';
-    }
-}
-
-sub _get_open_mode_fcntl {
-    my $fh = shift;
-
-    my $flags = eval { no warnings 'uninitialized';
-                       fcntl($fh, F_GETFL, my $junk) };
-    return unless $flags;
-
-    my $is_append = $flags & O_APPEND;
-    if ($flags & O_WRONLY) {
-        return $is_append ? '>>' : '>';
-    } elsif ($flags & O_RDWR) {
-        return $is_append ? '+>>' : '+<';
-    } else {
-        return '<';
-    }
-}
-
-sub _get_open_mode {
-    my $fh = shift;
-
-    return _get_open_mode_fcntl($fh)
-            ||
-            ($HAS_FMODE && _get_open_mode_filehandle_fmode($fh));
-}
-
 sub encode {
     my $value = shift;
     my $path_expr = shift;
@@ -134,7 +88,6 @@ sub encode {
             }
             if (*{$value}{IO}) {
                 if( $tmpvalue{IO} = encode(fileno(*{$value}{IO}), &$_p, $seen) ) {
-                    $tmpvalue{IOmode} = _get_open_mode(*{$value}{IO});
                     $tmpvalue{IOseek} = sysseek($value, 0, 1);
                 }
             }
@@ -147,8 +100,6 @@ sub encode {
             my($pattern, $modifiers);
             if ($^V ge v5.9.5) {
                 require re;
-            }
-            if (defined &re::regexp_pattern) {
                 ($pattern, $modifiers) = re::regexp_pattern($value);
             } else {
                 $value = "$value";
@@ -282,22 +233,6 @@ sub _create_anon_ref_of_type {
     }
 }
 
-sub _recreate_fh {
-    my($fileno, $mode) = @_;
-
-    my $fh;
-    if ($mode) {
-        open($fh, $mode . '&=', $fileno)
-            || Carp::carp("Couldn't open filehandle for descriptor $fileno with mode $mode: $!");
-
-    } else {
-        open($fh, '>&=', $fileno)
-        || open($fh, '<&=', $fileno)
-        || Carp::carp("Couldn't open filehandle for descriptor $fileno: $!");
-    }
-    return $fh;
-}
-
 sub decode {
     my($input, $recursive_queue, $recurse_fill) = @_;
 
@@ -350,10 +285,12 @@ sub decode {
         $rv = _create_anon_ref_of_type('GLOB', $value->{PACKAGE}, $value->{NAME});
 
         foreach my $type ( keys %$value ) {
-            next if ($type eq 'NAME' or $type eq 'PACKAGE' or $type eq 'IOseek' or $type eq 'IOmode');
+            next if ($type eq 'NAME' or $type eq 'PACKAGE' or $type eq 'IOseek');
             if ($type eq 'IO') {
                 if (my $fileno = $value->{IO}) {
-                    $rv = _recreate_fh($fileno, $value->{IOmode});
+                    open($rv, '>&=', $fileno)
+                    || open($rv, '<&=', $fileno)
+                    || Carp::carp("Couldn't open filehandle for descriptor $fileno: $!");
                 }
             } elsif ($type eq 'CODE') {
                 *{$rv} = \&_dummy_sub unless ($is_real_glob);
@@ -483,39 +420,20 @@ JSON::encode_json().  encode_json() cannot handle Perl-specific data like
 blessed references or typeglobs.  Non-reference scalar values like numbers
 and strings are returned unchanged.  For all references, encode()
 returns a hashref with these keys
-
-=over 4
-
-=item * __reftype
-
-String indicating the type of reference, as returned by Scalar::Util::reftype()
-
-=item * __refaddr
-
-Memory address of the reference, as returned by Scalar::Util::refaddr()
-
-=item * __blessed
-
-Package this reference is blessed into, as returned by Scalar::Util::blessed.
-
-=item * __value
-
-Reference to the unblessed data.
-
-=item * __tied
-
-The original value hidden by the tie() operation.
-
-=item * __recursive
-
-Flag indicating this reference was seen before
-
-=back
+  __reftype     String indicating the type of reference, as
+                  returned by Scalar::Util::reftype()
+  __refaddr     Memory address of the reference, as returned by
+                  Scalar::Util::refaddr()
+  __blessed     Package this reference is blessed into, as returned
+                  by Scalar::Util::blessed.
+  __value       Reference to the unblessed data.
+  __tied        The original value hidden by the tie() operation.
+  __recursive   Flag indicating this reference was seen before
 
 If the reference was not blessed or tied, then the __blessed and/or __tied keys
 will not be present.
 
-C<__value> is generally a copy of the underlying data.  For example, if the input
+__value is generally a copy of the underlying data.  For example, if the input
 value is an hashref, then __value will also be a hashref containing the input
 value's kays and values.  For typeblobs and glob refs, __value will be a
 hashref with the keys NAME, PACKAGE, SCALAR, ARRAY, HASH, IO and CODE.  For
@@ -524,48 +442,26 @@ modifiers.  For coderefs, __value will be the stringified reference, like
 "CODE=(0x12345678)".  For v-strings and v-string refs, __value will by an
 arrayref containing the integers making up the v-string.
 
-For tied objects, C<__tied> will be contain the original value hidden by tie()
+For tied objects, __tied will be contain the original value hidden by tie()
 and __value will contain the tied data.  The original data is retrieved by:
+    * call tied() to get a copy of the tied data
+    * localize the UNTIE method in the appropriate class
+    * untie the variable
+    * save a copy of the original value
+    * localize the appropriate TIE* mythod to return the tied data
+    * call tie() to retie the variable
 
-=over 4
-
-=item *
-
-call tied() to get a copy of the tied data
-
-=item *
-
-localize the UNTIE method in the appropriate class
-
-=item *
-
-untie the variable
-
-=item *
-
-save a copy of the original value
-
-=item *
-
-localize the appropriate TIE* mythod to return the tied data
-
-=item *
-
-call tie() to retie the variable
-
-=back
-
-if C<__recursive> is true, then __value will contain a string representation
+if __recursive is true, then __value will contain a string representation
 of the first place this reference was seen in the data structure.
 
 encode() handles arbitrarily nested data structures, meaning that
 values in the __values slot may also be encoded this way.
 
-=item decode
+=item deocde
 
 Accepts a single value and returns a copy of the data structure originally
 passed to encode().  __refaddr information is discarded and new copies of
-nested data structures is created.  Self-referential data is re-linked to the
+nested data structures is created.  Self-referential is re-linked to the
 appropriate placxe in the new copy.  Blessed references are re-bless into
 the original packages.
 
@@ -573,10 +469,7 @@ Tied variables are re-tied by localizing the appropriate TIE* method to return
 the tied data.  The variable's original data is filled in before calling tie().
 
 The IO slot of typeglobs is recreated by opening the handle with the same
-descriptor number and open mode.  It will first try fcntl() with F_GETFL
-to determine the open mode, falling back to using FileHandle::Fmode if it's
-available.  Finally, it will first try re-opening the file descriptor in
-read mode, then write mode.
+descriptor number.
 
 Coderefs cannot be decoded properly.  They are recreated by returning a
 reference to a dummy sub that returns a message explaning the situation.
@@ -585,7 +478,7 @@ reference to a dummy sub that returns a message explaning the situation.
 
 =head1 SEE ALSO
 
-L<JSON>, L<Sereal>, L<Data::Dumper>, L<FileHandle::Fmode>
+Devel::hdb
 
 =head1 AUTHOR
 
@@ -593,5 +486,5 @@ Anthony Brummett <brummett@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2016, Anthony Brummett.  This module is free software. It may
+Copyright 2014, Anthony Brummett.  This module is free software. It may
 be used, redistributed and/or modified under the same terms as Perl itself.
